#from pymatgen.electronic_structure.plotter import BSPlotter
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
import math
import numpy as np
#
def get_band_energies(filename, top_valbnd_idx):
    #
    f = open(filename,"r")
    lines = f.readlines()
    f.close()
    kpt_distance = []
    bs_energies = []
    energies = []
    distance = []
    count_bnd = 0
    for line in lines:
        sline = line.split()
        if len(sline) < 1:
            count_bnd += 1

            if count_bnd == top_valbnd_idx:
                vbm = max(energies)
            elif count_bnd == top_valbnd_idx + 1:
                cbm = min(energies)
            else:
                pass

            bs_energies.append(np.array(energies))
            kpt_distance.append(np.array(distance))
            energies = []
            distance = []
        else:
            distance.append(float(sline[0]))
            energies.append(float(sline[1]))

    return kpt_distance, bs_energies, vbm, cbm
#
#
if __name__ == "__main__":
    top_valbnd_dft = 26
    filename = "dft_bs.dat"
    filename_wan = "MoS2_band.dat"
    top_valbnd_wan = 2
    filename_gnu = "MoS2_band.gnu"
    ylims = (-1,3)
    less_dense = 1
    max_froz = 8.55
    #
    kpt_distance, bs_energies, vbm_dft, cbm_dft = get_band_energies(filename, top_valbnd_dft)
    kpt_distance_wan, bs_energies_wan, vbm_wan, cbm_wan = get_band_energies(filename_wan, top_valbnd_wan)
    print("vbm_dft", vbm_dft, "cbm_dft", cbm_dft)
    print("vbm_wan", vbm_wan, "cbm_wan", cbm_wan)
    #
    ratio = max(kpt_distance[0])/max(kpt_distance_wan[0])
    #
    xtics = []
    with open(filename_gnu,"r") as f:
        for line in f:
            if "set xtics" in line:
                cut_line = line[11:-2]
                scut_line = cut_line.split(",")
                for elem in scut_line:
                    selem = elem.split()
                    xtics.append([selem[0].replace("\"",""), float(selem[1])])
    f.close()

    width=8
    ticksize = int(width * 2.5)
    golden_ratio = (math.sqrt(5) - 1) / 2
    #height = int(width * golden_ratio)
    adjust_ratio = 5./6.
    height = int(width * adjust_ratio)
    #
    plt.figure(figsize=(width, height), facecolor="w")
    #plt.figure(figsize=(height, width), facecolor="w")
    xtick_labels = []
    xticks = []
    for xtic in xtics:
        #print(xtic)
        plt.plot([xtic[1], xtic[1]], [ylims[0], ylims[1]], color='black', linewidth=0.5)
        xticks.append(xtic[1])
        if xtic[0] == "G": xtic[0] = "$\Gamma$"
        xtick_labels.append(xtic[0])
    plt.xticks(xticks, xtick_labels, fontsize=15)
    #
    for idx, distance in enumerate(kpt_distance):
        if idx < len(kpt_distance) - 1:
            plt.plot(distance/ratio, bs_energies[idx]-vbm_dft, color="darkgrey", linewidth=1)
        else:
            plt.plot(distance/ratio, bs_energies[idx]-vbm_dft, color="darkgrey", linewidth=1, label="DFT")
    #        plt.plot(distance/ratio, bs_energies[idx]-vbm, color="darkgrey", linewidth=1.2)

    for idx, distance in enumerate(kpt_distance_wan):
        if idx < len(kpt_distance_wan) - 1:
            ndistance = []
            nbs_energies_wan = []
            for ii in range(len(distance)):
                if ii%less_dense == 0:
                    ndistance.append(distance[ii])
                    nbs_energies_wan.append(bs_energies_wan[idx][ii])
            plt.plot(ndistance, np.array(nbs_energies_wan) - vbm_wan, color="#1F75FE", linewidth=1)
        else:
            ndistance = []
            nbs_energies_wan = []
            for ii in range(len(distance)):
                if ii%less_dense == 0:
                    ndistance.append(distance[ii])
                    nbs_energies_wan.append(bs_energies_wan[idx][ii])
            plt.plot(ndistance, np.array(nbs_energies_wan) - vbm_wan, color="#1F75FE", linewidth=1, label="Wan")
    #
    #plt.plot([min(ndistance), max(ndistance)], [max_froz-vbm_wan, max_froz-vbm_wan], "k-", linewidth=0.8)
    #plt.legend(loc="upper right", fancybox=True, framealpha=1.0, fontsize=12)
    plt.ylim(ylims[0], ylims[1])
    plt.yticks(fontsize=12)
    plt.xlim(0, max(kpt_distance_wan[0]) + 1e-4)
    #plt.xlabel("Wave vector")
    plt.ylabel("$E - E_{VBM}$ (eV)", fontsize=14)
    plt.legend(fontsize=16, loc='upper right')
    plt.tight_layout()
    plt.savefig("bandstruct3.pdf", format="pdf")
    plt.show()
